# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import scheduling_pb2 as scheduling_dot_scheduling__pb2


class SchedulingServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/Get',
        request_serializer=scheduling_dot_scheduling__pb2.GetRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetReply.FromString,
        )
    self.GetMany = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetMany',
        request_serializer=scheduling_dot_scheduling__pb2.GetManyRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetManyReply.FromString,
        )
    self.GetByUser = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByUser',
        request_serializer=scheduling_dot_scheduling__pb2.GetByUserRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByUserReply.FromString,
        )
    self.GetByOrg = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByOrg',
        request_serializer=scheduling_dot_scheduling__pb2.GetByOrgRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByOrgReply.FromString,
        )
    self.GetByWorkspace = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByWorkspace',
        request_serializer=scheduling_dot_scheduling__pb2.GetByWorkspaceRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByWorkspaceReply.FromString,
        )
    self.GetByExperiment = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByExperiment',
        request_serializer=scheduling_dot_scheduling__pb2.GetByExperimentRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByExperimentReply.FromString,
        )
    self.GetByAccessToken = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByAccessToken',
        request_serializer=scheduling_dot_scheduling__pb2.GetByAccessTokenRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByAccessTokenReply.FromString,
        )


class SchedulingServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetMany(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByOrg(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByWorkspace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByExperiment(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByAccessToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SchedulingServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=scheduling_dot_scheduling__pb2.GetRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetReply.SerializeToString,
      ),
      'GetMany': grpc.unary_unary_rpc_method_handler(
          servicer.GetMany,
          request_deserializer=scheduling_dot_scheduling__pb2.GetManyRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetManyReply.SerializeToString,
      ),
      'GetByUser': grpc.unary_unary_rpc_method_handler(
          servicer.GetByUser,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByUserRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByUserReply.SerializeToString,
      ),
      'GetByOrg': grpc.unary_unary_rpc_method_handler(
          servicer.GetByOrg,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByOrgRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByOrgReply.SerializeToString,
      ),
      'GetByWorkspace': grpc.unary_unary_rpc_method_handler(
          servicer.GetByWorkspace,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByWorkspaceRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByWorkspaceReply.SerializeToString,
      ),
      'GetByExperiment': grpc.unary_unary_rpc_method_handler(
          servicer.GetByExperiment,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByExperimentRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByExperimentReply.SerializeToString,
      ),
      'GetByAccessToken': grpc.unary_unary_rpc_method_handler(
          servicer.GetByAccessToken,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByAccessTokenRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByAccessTokenReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.scheduling.SchedulingService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
