# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace/workspace.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='workspace/workspace.proto',
  package='chaosplatform.workspace',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x19workspace/workspace.proto\x12\x17\x63haosplatform.workspace\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\";\n\x0c\x43ollaborator\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\x08\"\xeb\x01\n\tWorkspace\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x10\n\x08org_name\x18\x04 \x01(\t\x12\x0c\n\x04kind\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\rcollaborators\x18\x08 \x03(\x0b\x32%.chaosplatform.workspace.Collaborator\x12&\n\x08settings\x18\t \x01(\x0b\x32\x14.google.protobuf.Any\">\n\rCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\"D\n\x0b\x43reateReply\x12\x35\n\tworkspace\x18\x02 \x01(\x0b\x32\".chaosplatform.workspace.Workspace\"\x1b\n\rDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\r\n\x0b\x44\x65leteReply\"\x18\n\nGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"A\n\x08GetReply\x12\x35\n\tworkspace\x18\x01 \x01(\x0b\x32\".chaosplatform.workspace.Workspace\"\x1d\n\x0eGetManyRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"F\n\x0cGetManyReply\x12\x36\n\nworkspaces\x18\x01 \x03(\x0b\x32\".chaosplatform.workspace.Workspace\"#\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"H\n\x0eGetByUserReply\x12\x36\n\nworkspaces\x18\x01 \x03(\x0b\x32\".chaosplatform.workspace.Workspace2\xca\x03\n\x10WorkspaceService\x12V\n\x06\x43reate\x12&.chaosplatform.workspace.CreateRequest\x1a$.chaosplatform.workspace.CreateReply\x12M\n\x03Get\x12#.chaosplatform.workspace.GetRequest\x1a!.chaosplatform.workspace.GetReply\x12Y\n\x07GetMany\x12\'.chaosplatform.workspace.GetManyRequest\x1a%.chaosplatform.workspace.GetManyReply\x12V\n\x06\x44\x65lete\x12&.chaosplatform.workspace.DeleteRequest\x1a$.chaosplatform.workspace.DeleteReply\x12\\\n\x06\x42yUser\x12).chaosplatform.workspace.GetByUserRequest\x1a\'.chaosplatform.workspace.GetByUserReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_COLLABORATOR = _descriptor.Descriptor(
  name='Collaborator',
  full_name='chaosplatform.workspace.Collaborator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.Collaborator.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.workspace.Collaborator.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='chaosplatform.workspace.Collaborator.owner', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=173,
)


_WORKSPACE = _descriptor.Descriptor(
  name='Workspace',
  full_name='chaosplatform.workspace.Workspace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.Workspace.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.workspace.Workspace.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.workspace.Workspace.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_name', full_name='chaosplatform.workspace.Workspace.org_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='chaosplatform.workspace.Workspace.kind', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_on', full_name='chaosplatform.workspace.Workspace.created_on', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaborators', full_name='chaosplatform.workspace.Workspace.collaborators', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='chaosplatform.workspace.Workspace.settings', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=411,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='chaosplatform.workspace.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.workspace.CreateRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.workspace.CreateRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.workspace.CreateRequest.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=475,
)


_CREATEREPLY = _descriptor.Descriptor(
  name='CreateReply',
  full_name='chaosplatform.workspace.CreateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='chaosplatform.workspace.CreateReply.workspace', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=545,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='chaosplatform.workspace.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.DeleteRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=574,
)


_DELETEREPLY = _descriptor.Descriptor(
  name='DeleteReply',
  full_name='chaosplatform.workspace.DeleteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=589,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='chaosplatform.workspace.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.GetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=615,
)


_GETREPLY = _descriptor.Descriptor(
  name='GetReply',
  full_name='chaosplatform.workspace.GetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='chaosplatform.workspace.GetReply.workspace', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=682,
)


_GETMANYREQUEST = _descriptor.Descriptor(
  name='GetManyRequest',
  full_name='chaosplatform.workspace.GetManyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='chaosplatform.workspace.GetManyRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=713,
)


_GETMANYREPLY = _descriptor.Descriptor(
  name='GetManyReply',
  full_name='chaosplatform.workspace.GetManyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaces', full_name='chaosplatform.workspace.GetManyReply.workspaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=785,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.workspace.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.workspace.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=822,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.workspace.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaces', full_name='chaosplatform.workspace.GetByUserReply.workspaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=824,
  serialized_end=896,
)

_WORKSPACE.fields_by_name['created_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKSPACE.fields_by_name['collaborators'].message_type = _COLLABORATOR
_WORKSPACE.fields_by_name['settings'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CREATEREPLY.fields_by_name['workspace'].message_type = _WORKSPACE
_GETREPLY.fields_by_name['workspace'].message_type = _WORKSPACE
_GETMANYREPLY.fields_by_name['workspaces'].message_type = _WORKSPACE
_GETBYUSERREPLY.fields_by_name['workspaces'].message_type = _WORKSPACE
DESCRIPTOR.message_types_by_name['Collaborator'] = _COLLABORATOR
DESCRIPTOR.message_types_by_name['Workspace'] = _WORKSPACE
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateReply'] = _CREATEREPLY
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteReply'] = _DELETEREPLY
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetReply'] = _GETREPLY
DESCRIPTOR.message_types_by_name['GetManyRequest'] = _GETMANYREQUEST
DESCRIPTOR.message_types_by_name['GetManyReply'] = _GETMANYREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Collaborator = _reflection.GeneratedProtocolMessageType('Collaborator', (_message.Message,), dict(
  DESCRIPTOR = _COLLABORATOR,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.Collaborator)
  ))
_sym_db.RegisterMessage(Collaborator)

Workspace = _reflection.GeneratedProtocolMessageType('Workspace', (_message.Message,), dict(
  DESCRIPTOR = _WORKSPACE,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.Workspace)
  ))
_sym_db.RegisterMessage(Workspace)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateReply = _reflection.GeneratedProtocolMessageType('CreateReply', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.CreateReply)
  ))
_sym_db.RegisterMessage(CreateReply)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteReply = _reflection.GeneratedProtocolMessageType('DeleteReply', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.DeleteReply)
  ))
_sym_db.RegisterMessage(DeleteReply)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetReply = _reflection.GeneratedProtocolMessageType('GetReply', (_message.Message,), dict(
  DESCRIPTOR = _GETREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetReply)
  ))
_sym_db.RegisterMessage(GetReply)

GetManyRequest = _reflection.GeneratedProtocolMessageType('GetManyRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetManyRequest)
  ))
_sym_db.RegisterMessage(GetManyRequest)

GetManyReply = _reflection.GeneratedProtocolMessageType('GetManyReply', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetManyReply)
  ))
_sym_db.RegisterMessage(GetManyReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)



_WORKSPACESERVICE = _descriptor.ServiceDescriptor(
  name='WorkspaceService',
  full_name='chaosplatform.workspace.WorkspaceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=899,
  serialized_end=1357,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='chaosplatform.workspace.WorkspaceService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='chaosplatform.workspace.WorkspaceService.Get',
    index=1,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMany',
    full_name='chaosplatform.workspace.WorkspaceService.GetMany',
    index=2,
    containing_service=None,
    input_type=_GETMANYREQUEST,
    output_type=_GETMANYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='chaosplatform.workspace.WorkspaceService.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ByUser',
    full_name='chaosplatform.workspace.WorkspaceService.ByUser',
    index=4,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKSPACESERVICE)

DESCRIPTOR.services_by_name['WorkspaceService'] = _WORKSPACESERVICE

# @@protoc_insertion_point(module_scope)
