# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import experiment_pb2 as experiment_dot_experiment__pb2


class ExperimentServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/Get',
        request_serializer=experiment_dot_experiment__pb2.GetRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetReply.FromString,
        )
    self.GetMany = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetMany',
        request_serializer=experiment_dot_experiment__pb2.GetManyRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetManyReply.FromString,
        )
    self.GetByUser = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetByUser',
        request_serializer=experiment_dot_experiment__pb2.GetByUserRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetByUserReply.FromString,
        )
    self.GetByOrg = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetByOrg',
        request_serializer=experiment_dot_experiment__pb2.GetByOrgRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetByOrgReply.FromString,
        )
    self.GetByWorkspace = channel.unary_unary(
        '/chaosplatform.experiment.ExperimentService/GetByWorkspace',
        request_serializer=experiment_dot_experiment__pb2.GetByWorkspaceRequest.SerializeToString,
        response_deserializer=experiment_dot_experiment__pb2.GetByWorkspaceReply.FromString,
        )


class ExperimentServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetMany(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByOrg(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByWorkspace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ExperimentServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=experiment_dot_experiment__pb2.GetRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetReply.SerializeToString,
      ),
      'GetMany': grpc.unary_unary_rpc_method_handler(
          servicer.GetMany,
          request_deserializer=experiment_dot_experiment__pb2.GetManyRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetManyReply.SerializeToString,
      ),
      'GetByUser': grpc.unary_unary_rpc_method_handler(
          servicer.GetByUser,
          request_deserializer=experiment_dot_experiment__pb2.GetByUserRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetByUserReply.SerializeToString,
      ),
      'GetByOrg': grpc.unary_unary_rpc_method_handler(
          servicer.GetByOrg,
          request_deserializer=experiment_dot_experiment__pb2.GetByOrgRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetByOrgReply.SerializeToString,
      ),
      'GetByWorkspace': grpc.unary_unary_rpc_method_handler(
          servicer.GetByWorkspace,
          request_deserializer=experiment_dot_experiment__pb2.GetByWorkspaceRequest.FromString,
          response_serializer=experiment_dot_experiment__pb2.GetByWorkspaceReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.experiment.ExperimentService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
