# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import registration_pb2 as registration_dot_registration__pb2


class RegistrationServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/chaosplatform.registration.RegistrationService/Create',
        request_serializer=registration_dot_registration__pb2.CreateRequest.SerializeToString,
        response_deserializer=registration_dot_registration__pb2.CreateReply.FromString,
        )
    self.Delete = channel.unary_unary(
        '/chaosplatform.registration.RegistrationService/Delete',
        request_serializer=registration_dot_registration__pb2.DeleteRequest.SerializeToString,
        response_deserializer=registration_dot_registration__pb2.DeleteReply.FromString,
        )
    self.GetById = channel.unary_unary(
        '/chaosplatform.registration.RegistrationService/GetById',
        request_serializer=registration_dot_registration__pb2.GetByIdRequest.SerializeToString,
        response_deserializer=registration_dot_registration__pb2.GetByIdReply.FromString,
        )


class RegistrationServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetById(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RegistrationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=registration_dot_registration__pb2.CreateRequest.FromString,
          response_serializer=registration_dot_registration__pb2.CreateReply.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=registration_dot_registration__pb2.DeleteRequest.FromString,
          response_serializer=registration_dot_registration__pb2.DeleteReply.SerializeToString,
      ),
      'GetById': grpc.unary_unary_rpc_method_handler(
          servicer.GetById,
          request_deserializer=registration_dot_registration__pb2.GetByIdRequest.FromString,
          response_serializer=registration_dot_registration__pb2.GetByIdReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.registration.RegistrationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
