# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: registration/registration.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='registration/registration.proto',
  package='chaosplatform.registration',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1fregistration/registration.proto\x12\x1a\x63haosplatform.registration\"\x8c\x01\n\x0cRegistration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x18\n\x10is_authenticated\x18\x05 \x01(\x08\x12\x11\n\tis_active\x18\x06 \x01(\x08\x12\x14\n\x0cis_anonymous\x18\x07 \x01(\x08\">\n\rCreateRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"M\n\x0b\x43reateReply\x12>\n\x0cregistration\x18\x01 \x01(\x0b\x32(.chaosplatform.registration.Registration\"\x1b\n\rDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\r\n\x0b\x44\x65leteReply\"\x1c\n\x0eGetByIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\"N\n\x0cGetByIdReply\x12>\n\x0cregistration\x18\x01 \x01(\x0b\x32(.chaosplatform.registration.Registration2\xb2\x02\n\x13RegistrationService\x12\\\n\x06\x43reate\x12).chaosplatform.registration.CreateRequest\x1a\'.chaosplatform.registration.CreateReply\x12\\\n\x06\x44\x65lete\x12).chaosplatform.registration.DeleteRequest\x1a\'.chaosplatform.registration.DeleteReply\x12_\n\x07GetById\x12*.chaosplatform.registration.GetByIdRequest\x1a(.chaosplatform.registration.GetByIdReplyb\x06proto3')
)




_REGISTRATION = _descriptor.Descriptor(
  name='Registration',
  full_name='chaosplatform.registration.Registration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.registration.Registration.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.registration.Registration.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.registration.Registration.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='chaosplatform.registration.Registration.email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_authenticated', full_name='chaosplatform.registration.Registration.is_authenticated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='chaosplatform.registration.Registration.is_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_anonymous', full_name='chaosplatform.registration.Registration.is_anonymous', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=204,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='chaosplatform.registration.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.registration.CreateRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.registration.CreateRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='chaosplatform.registration.CreateRequest.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=268,
)


_CREATEREPLY = _descriptor.Descriptor(
  name='CreateReply',
  full_name='chaosplatform.registration.CreateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='registration', full_name='chaosplatform.registration.CreateReply.registration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=347,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='chaosplatform.registration.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.registration.DeleteRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=376,
)


_DELETEREPLY = _descriptor.Descriptor(
  name='DeleteReply',
  full_name='chaosplatform.registration.DeleteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=391,
)


_GETBYIDREQUEST = _descriptor.Descriptor(
  name='GetByIdRequest',
  full_name='chaosplatform.registration.GetByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.registration.GetByIdRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=421,
)


_GETBYIDREPLY = _descriptor.Descriptor(
  name='GetByIdReply',
  full_name='chaosplatform.registration.GetByIdReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='registration', full_name='chaosplatform.registration.GetByIdReply.registration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=501,
)

_CREATEREPLY.fields_by_name['registration'].message_type = _REGISTRATION
_GETBYIDREPLY.fields_by_name['registration'].message_type = _REGISTRATION
DESCRIPTOR.message_types_by_name['Registration'] = _REGISTRATION
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateReply'] = _CREATEREPLY
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteReply'] = _DELETEREPLY
DESCRIPTOR.message_types_by_name['GetByIdRequest'] = _GETBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetByIdReply'] = _GETBYIDREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Registration = _reflection.GeneratedProtocolMessageType('Registration', (_message.Message,), dict(
  DESCRIPTOR = _REGISTRATION,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.Registration)
  ))
_sym_db.RegisterMessage(Registration)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateReply = _reflection.GeneratedProtocolMessageType('CreateReply', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREPLY,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.CreateReply)
  ))
_sym_db.RegisterMessage(CreateReply)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteReply = _reflection.GeneratedProtocolMessageType('DeleteReply', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREPLY,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.DeleteReply)
  ))
_sym_db.RegisterMessage(DeleteReply)

GetByIdRequest = _reflection.GeneratedProtocolMessageType('GetByIdRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYIDREQUEST,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.GetByIdRequest)
  ))
_sym_db.RegisterMessage(GetByIdRequest)

GetByIdReply = _reflection.GeneratedProtocolMessageType('GetByIdReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYIDREPLY,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.GetByIdReply)
  ))
_sym_db.RegisterMessage(GetByIdReply)



_REGISTRATIONSERVICE = _descriptor.ServiceDescriptor(
  name='RegistrationService',
  full_name='chaosplatform.registration.RegistrationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=504,
  serialized_end=810,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='chaosplatform.registration.RegistrationService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='chaosplatform.registration.RegistrationService.Delete',
    index=1,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetById',
    full_name='chaosplatform.registration.RegistrationService.GetById',
    index=2,
    containing_service=None,
    input_type=_GETBYIDREQUEST,
    output_type=_GETBYIDREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_REGISTRATIONSERVICE)

DESCRIPTOR.services_by_name['RegistrationService'] = _REGISTRATIONSERVICE

# @@protoc_insertion_point(module_scope)
